nwn
===

A python package with various modules for accessing Neverwinter Nights: Enhanced Edition
data formats and functionality.

Stability
---------

This package is currently in ALPHA state. API stability is not guaranteed.

Installation
------------

The package is available on PyPI and can be installed with pip:

.. code-block:: bash

    pip install nwn

Documentation
-------------

See the `documentation <https://niv.github.io/nwn.py/>`_ for usage.

License
-------

This package is licensed under the MIT license.
